function [FibCrackS, FibCrackL, FibCrackIn, FibCrackPar]  = SelFib(FibGeo, FibMat, FibInt, eta, Zr)

% function for the selection of fiber bridging crack
% non-parallel calculation
%
% in:   FibGeo - table of fibers (see GenFib.m)
%       FibMat - table of stochastic parameters of fibers (see GenMat.m)
%       FibInt - table of stochastic parameters of interface (see GenInt.m)
%       Zr - position of the crack
% out:  FibCrack_ - table of fibers bridging crack
%       FibCrackS - parameters on short embedded side
%            Column 1 - Ls [mm]
%            Column 2 - u0s [mm]
%            Column 3 - umaxs [mm]
%       FibCrackL - parameters on long embedded side
%            Column 1 - Ll [mm]
%            Column 2 - u0l [mm]
%            Column 3 - umaxl [mm]
%       FibCrackIn - pulling and rupture parameters
%            Column 1 - 0 - break of fiber [-] (0/1)
%            Column 1 - 0 - full extraction of fiber [-] (0/1)
%       FibCrackPar - material parameters
%            Column 1 - df - diameter of fiber [mm]
%            Column 2 - angle thau (angle from normal to the cross plane) [rad]
%            Column 3 - directional angle [rad]
%            Column 4 - Ef - Young modulus of fiber [MPa]
%            Column 5 - ftf - strength of fiber [MPa]
%            Column 6 - tau0 - frictional stress [MPa]
%            Column 7 - Gd - fracture energy [N/m]
%            Column 8 - beta - slip hardening coefficient [-]

n = size(FibGeo,1);
FibCrackS = zeros(1,3);
FibCrackL = zeros(1,3);
FibCrackPar = zeros(1,3);

m=1;
for i=1:n
	if ((FibGeo(i,3)<=Zr && FibGeo(i,6)>=Zr) || (FibGeo(i,3)>=Zr && FibGeo(i,6)<=Zr))
		Ls = min( (Zr-FibGeo(i,3))/sin(FibGeo(i,7)), (FibGeo(i,6)-Zr)/sin(FibGeo(i,7)));
		Ll = max( (Zr-FibGeo(i,3))/sin(FibGeo(i,7)), (FibGeo(i,6)-Zr)/sin(FibGeo(i,7)));
		u0s = (2*FibInt(i,1)*Ls^2*(1+eta))/(FibMat(i,3)*FibMat(i,2))+sqrt((8*FibInt(i,2)*Ls^2*(1+eta))/(FibMat(i,3)*FibMat(i,2)));
		u0l = (2*FibInt(i,1)*Ll^2*(1+eta))/(FibMat(i,3)*FibMat(i,2))+sqrt((8*FibInt(i,2)*Ll^2*(1+eta))/(FibMat(i,3)*FibMat(i,2)));
		
		FibCrackS(m,1) = Ls;
		FibCrackS(m,2) = u0s;
		
		FibCrackL(m,1) = Ll;
		FibCrackL(m,2) = u0l;
		
		FibCrackPar(m,1) = FibMat(i,2);
		FibCrackPar(m,2) = pi/2-abs(FibGeo(i,7));
		FibCrackPar(m,3) = FibGeo(i,8);
		FibCrackPar(m,4) = FibMat(i,3);
		FibCrackPar(m,5) = FibMat(i,4);
		FibCrackPar(m,6) = FibInt(i,1);
		FibCrackPar(m,7) = FibInt(i,2);
		FibCrackPar(m,8) = FibInt(i,3);
		
		m=m+1;
	end
end
FibCrackIn = zeros(size(FibCrackS,1),2);